<?php

namespace Drupal\unomi;

use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Class UnomiCookieManager
 *
 * @package Drupal\unomi
 */
class UnomiCookieManager {

  const COOKIE_NAME = 'DS_VARY_ML';

  /**
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * UnomiCookieManager constructor.
   *
   * @param \Symfony\Component\HttpFoundation\RequestStack $requestStack
   */
  public function __construct(RequestStack $requestStack) {
    $this->requestStack = $requestStack;
  }

  /**
   * Return the cookie values.
   *
   * When no segment is detected/returned from the cloud function, a cookie
   * with value '_unknown' is set. If no cookie is set, that functionally means
   * the same. So any falsy value gets cast to '_unknown'.
   *
   * @return array
   */
  public function getSegmentCookieValues() {
    $cookieValue = $this->requestStack->getCurrentRequest()->cookies->get(static::COOKIE_NAME, '_unknown');
    if (!$cookieValue) {
      $cookieValue = ['_unknown'];
    }
    $cookieValues = explode(", ", $cookieValue);
    return $cookieValues;
  }

}
